Music components - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Music components

1
Górą ty
GOLEC UORKIESTRA, Gromee, Bedoes
03:41
2
High Life
Daft Punk
03:21
3
Houdini
Foster The People
03:23
4
Safe And Sound
Capital Cities
03:12
5
Partied Out
Con Bro Chill
03:17
6
Runaway (U & I)
Galantis
03:47
7
Light It Up (feat. Nyla & Fuse ODG) - Remix
Major Lazer, Nyla, Fuse ODG
02:46
8
Hangover
Taio Cruz, Flo Rida
04:04
9
Shape of You
Ed Sheeran
03:53
10
Alone
Alan Walker
02:41
11
Langrennsfar
Ylvis
02:43
12
Skibidi - Romantic Edition
Little Big
03:12

### Top tracks

Shape of You
Ed Sheeran
Alone
Alan Walker
Langrennsfar
Ylvis
Skibidi - Romantic Edition
Little Big
Miracle
Caravan Palace
Different World (feat. CORSAK)
Alan Walker, K-391, Sofia Carson, CORSAK